#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_i18n.interfaces import INegotiator
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.interfaces import VIEW_SYSTEM_PERMISSION, MANAGE_SYSTEM_PERMISSION

# import packages
from pyams_form.form import AJAXEditForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_zmi.form import AdminDialogEditForm
from pyramid.view import view_config
from z3c.form import field

from pyams_i18n import _


@pagelet_config(name='properties.html', context=INegotiator, layer=IPyAMSLayer, permission=VIEW_SYSTEM_PERMISSION)
class NegotiatorPropertiesEditForm(AdminDialogEditForm):
    """Negotiator properties edit form"""

    prefix = 'negotiator_properties.'

    @property
    def title(self):
        return self.context.__name__

    legend = _("Update languages negotiator properties")

    fields = field.Fields(INegotiator)
    ajax_handler = 'properties.json'
    edit_permission = MANAGE_SYSTEM_PERMISSION

    def updateWidgets(self, prefix=None):
        super(NegotiatorPropertiesEditForm, self).updateWidgets()
        self.widgets['server_language'].addClass('select2')
        self.widgets['policy'].addClass('select2')


@view_config(name='properties.json', context=INegotiator, request_type=IPyAMSLayer,
             permission=MANAGE_SYSTEM_PERMISSION, renderer='json', xhr=True)
class NegotiatorPropertiesAJAXEditForm(AJAXEditForm, NegotiatorPropertiesEditForm):
    """Negotiator properties edit form, AJAX renderer"""
